#
# spec file for package python-poppler-qt5
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 LISA GmbH, Bingen, Germany.
# Copyright (c) 2012 Johannes Engel <jcnengel@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-poppler-qt5
Version:        21.3.0
Release:        2.2
Summary:        Python binding to poppler-qt5
License:        LGPL-2.1-or-later
URL:            https://pypi.org/project/python-poppler-qt5/
Source0:        https://files.pythonhosted.org/packages/source/p/python-poppler-qt5/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module pyqt-builder}
BuildRequires:  %{python_module qt5-devel}
BuildRequires:  %{python_module sip-devel > 5.3}
BuildRequires:  libpoppler-qt5-devel
BuildRequires:  python-pyqt-rpm-macros
BuildRequires:  python-rpm-macros
%requires_eq    python-qt5

%python_subpackages

%description
A Python binding for libpoppler-qt5 that aims for completeness
and for being actively maintained.

%package devel
Summary:        Devel package for %{name}
Group:          Development/Languages/Python
Requires:       libpoppler-qt5-devel
Requires:       python-qt5-devel
Requires:       python-sip-devel

%description devel
A Python binding for libpoppler-qt5 that aims for completeness
and for being actively maintained.

This package contains the SIP and Qscintilla API files to build
python packages using python-poppler

%prep
%autosetup -p1
# use the aliased keyword for subprocess.check_call() that is also known by Python 3.6 gh#frescobaldi/python-poppler-qt5#44
sed -i 's/text=True/universal_newlines=True/' project.py

%build
# https://github.com/frescobaldi/python-poppler-qt5/issues/61
%pyqt_build -s %{quote:--qmake-setting 'CONFIG += c++17'}

%install
%pyqt_install

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python -c 'import popplerqt5; print(popplerqt5.version())'

%files %{python_files}
%license LICENSE
%doc ChangeLog README.rst TODO
%{python_sitearch}/popplerqt5*.so
%{python_sitearch}/python_poppler_qt5-%{version}*-info

%files %{python_files devel}
%license LICENSE
%{python_sitearch}/PyQt5/bindings/popplerqt5
%{_libqt5_datadir}/qsci/api/python_%{python_bin_suffix}/python-poppler-qt5.api

%changelog
* Mon Jan 29 2024 Ben Greiner <code@bnavigator.de>
- Enable SLE15 python module
- Force c++17 gh#frescobaldi/python-poppler-qt5#61
* Thu May  5 2022 Cor Blom <cornelis@solcon.nl>
- Update to 21.3.0:
  Fix #43: Building 21.1.0 fails with unsupported function return type
  by Ben Greiner
- Drop patch merged upstream:
  * python-poppler-qt5-mapqvector.patch
- Drop support for sip4, which means only 15.4 and higher are now
  supported (also solves boo#1198526)
* Tue Feb 23 2021 Ben Greiner <code@bnavigator.de>
- Update to 21.1.0
  * Most new Qt5 api methods added upto poppler-qt5 21.01 (WB)
  * Deprecated C API calls updated (woodlandhunter)
  * Add support for building with SIP v5 (#41, Dmitry Shachnev)
- Drop patches merged upstream
  * poppler-qt5-pr33-sip5.patch
  * poppler-qt5-pr41-sip5.patch
- Add python-poppler-qt5-mapqvector.patch
  gh#frescobaldi/python-poppler-qt5#45
- Reinstate the skip for python2
* Tue Feb 23 2021 Ben Greiner <code@bnavigator.de>
- Reinstate multiversion build. The only fix needed was
  gh#frescobaldi/python-poppler-qt5#44
* Thu Feb  4 2021 Cor Blom <cornelis@solcon.nl>
- Add not why we do not use multiversion for this package
- Add note why we do not update to 21.1.0
* Thu Jan 21 2021 Cor Blom <cornelis@solcon.nl>
- Limit build set to python3 (remove skip python2), so that the
  package builds again. TODO: figure out how to deal with multi-
  version python installation and usefulness for this package.
* Sat Oct 10 2020 Benjamin Greiner <code@bnavigator.de>
- Use SIP5
  * poppler-qt5-pr33-sip5.patch
    gh#frescobaldi/python-poppler-qt5#33
  * poppler-qt5-pr41-sip5.patch
    gh#frescobaldi/python-poppler-qt5#41
- SIP5 creates files for SIP bindings and Qscintilla API
  * new devel package
* Thu Sep 10 2020 Benjamin Greiner <code@bnavigator.de>
- Fix obsoletes to work with python singlespec
- Enforce sip4 gh#frescobaldi/python-poppler-qt5#38
* Fri Jan  3 2020 Cor Blom <cornelis@solcon.nl>
- Add Obsoletes: python-poppler-qt5 to prevent file conflict in
  Leap 15.2
* Fri Dec 27 2019 Cor Blom <cornelis@solcon.nl>
- Update to version 0.75.0:
  * add LinkOCGState
  * Enable C++11 support in setup.py (Alex Ball)
  * Fix build error on MacOSX (Davide Liessi)
  * Added more methods in Poppler Qt5 api (WB)
- Switch back to official project, which is alive again
- Update URLs to the official ones
* Sat Dec 15 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Require specific version of SIP (boo#1119580)
* Sat Dec 15 2018 Cor Blom <cornelis@solcon.nl>
- Require specific python-qt5 version (boo#1119580)
* Tue May 29 2018 mcepl@suse.com
- Clean SPEC file
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu Mar 23 2017 cornelis@solcon.nl
- Change RPM Group to Development/Languages/Python
* Wed Jan 25 2017 cornelis@solcon.nl
- Switch to the zehome fork, which is better maintained at the
  moment and use released tarball.
* Tue Jan 24 2017 cornelis@solcon.nl
- Update to git to get necessary fixes
* Mon Jan 23 2017 cornelis@solcon.nl
- Initial package, replaces python-poppler-qt4
